@@ -68,6 +68,10 @@ bayesfactor_inclusion <- function(models, match_models = FALSE, prior_odds = NUL
 
 #' @export
 bayesfactor_inclusion.bayesfactor_models <- function(models, match_models = FALSE, prior_odds = NULL, ...) {
+  if (isTRUE(attr(models, "unsupported_models"))) {
+    stop("Can not compute inclusion Bayes factors - passed models are not (yet) supported.", call. = FALSE)
+  }
+
   # Build Models Table #
   df.model <- .get_model_table(models, priorOdds = prior_odds)
   effnames <- colnames(df.model)[-(1:3)]
@@ -177,16 +181,27 @@ bayesfactor_inclusion.BFBayesFactor <- function(models, match_models = FALSE, pr
 
   # add effects table
   make_terms <- function(formula) {
+    sort_interactions <- function(x) {
+      if (grepl("\\:", x)) {
+        effs <- unlist(strsplit(x, "\\:"))
+        x <- paste0(sort(effs), collapse = ":")
+      }
+      x
+    }
     formula.f <- stats::as.formula(paste0("~", formula))
     all.terms <- attr(stats::terms(formula.f), "term.labels")
 
+    # Fixed
     fix_trms <- all.terms[!grepl("\\|", all.terms)] # no random
+    if (length(fix_trms) > 0) {
+      fix_trms <- sapply(fix_trms, sort_interactions)
+    }
 
+    # Random
     random_parts <- paste0(all.terms[grepl("\\|", all.terms)]) # only random
     if (length(random_parts) == 0) {
       return(fix_trms)
     }
-
     random_units <- sub("^.+\\|\\s+", "", random_parts)
     tmp_random <- lapply(
       sub("\\|.+$", "", random_parts),
@@ -197,6 +212,7 @@ bayesfactor_inclusion.BFBayesFactor <- function(models, match_models = FALSE, pr
 
     for (i in seq_along(random_parts)) {
       tmp_trms <- attr(stats::terms.formula(tmp_random[[i]]), "term.labels")
+      tmp_trms <- sapply(tmp_trms, sort_interactions)
 
       if (!any(unlist(strsplit(as.character(tmp_random[[i]])[[2]], " \\+ ")) == "0")) {
         tmp_trms <- c("1", tmp_trms)
