@@ -3,7 +3,7 @@
 #' @param object A list.
 #' @param name Name of column of keys in the case the output is a dataframe.
 #' @keywords internal
-flatten_list <- function(object, name = "name") {
+.flatten_list <- function(object, name = "name") {
   if (length(object) == 1) {
     object[[1]]
   } else if (all(sapply(object, is.data.frame))) {
